"""Request arguments that are passed in all the SDK requests.

Usage::

    from nebius.aio.request_kwargs import RequestKwargs
    from typing_extensions import Unpack  # or from typing import Unpack in Python 3.11+
    from nebius.api.nebius... import SomeService, SomeRequest # illustrative only

    def my_request_wrapper(some_arg, **kwargs: Unpack[RequestKwargs]):
        request = SomeRequest(arg=some_arg) # build your request here

        return SomeService(sdk).some_method( # initialize your service client
            request,
            **kwargs, # pass the request kwargs along with the service call
        )

    result = await my_request_wrapper(
        some_arg="value",
        timeout=5.0,
        retries=2,
    )
"""

from collections.abc import Iterable
from typing import TypedDict

from grpc import CallCredentials, Compression

from nebius.base.protos.unset import UnsetType


class RequestKwargsForOperation(TypedDict, total=False):
    """Encapsulates the general keyword arguments for all requests, including operation
    wait requests, where some parameters are overridden or renamed. The full set of
    parameters is available in :class:`RequestKwargs`.

    :ivar metadata: Optional initial gRPC metadata to attach to the call.
    :type metadata: either :class:`nebius.base.metadata.Metadata`
        or list of ``(str, str)`` tuples.

    :ivar auth_timeout: Timeout budget (seconds) reserved for authorization
        flows plus the request execution. When provided the total authorization
        + request time will not exceed this value.
        Default is :data:`nebius.aio.request.DEFAULT_AUTH_TIMEOUT`.
        Provide `None` for infinite timeout.
    :type auth_timeout: optional `float` or `None`

    :ivar auth_options: Optional dictionary forwarded to the authenticator
        when performing authorization. See the authenticator documentation for
        provider-specific keys.
    :type auth_options: optional ``dict[str, str]``

    :ivar credentials: Optional gRPC :class:`CallCredentials` to use for the
        RPC invocation.
    :type credentials: optional :class:`grpc.CallCredentials`

    :ivar compression: Optional gRPC compression setting for the RPC.
    :type compression: optional :class:`grpc.Compression`
    """

    metadata: Iterable[tuple[str, str]] | None
    auth_timeout: float | None | UnsetType
    auth_options: dict[str, str] | None
    credentials: CallCredentials | None
    compression: Compression | None


class RequestKwargs(RequestKwargsForOperation, total=False):
    """Encapsulates the general keyword arguments for any request.

    :ivar timeout: Overall timeout (seconds) applied to the request execution
        portion. Or `None` for infinite timeout.
        Default is :data:`nebius.aio.request.DEFAULT_TIMEOUT`.
    :type timeout: optional `float` or `None`

    :ivar retries: Number of retry attempts for transient failures. Default is 3.
    :type retries: optional `int` or `None`

    :ivar per_retry_timeout: Timeout (seconds) applied to each retry attempt
        individually. You can pass `None` for infinite timeout. Default is
        :data:`nebius.aio.request.DEFAULT_PER_RETRY_TIMEOUT`.
    :type per_retry_timeout: optional `float` or `None`
    """

    timeout: float | None | UnsetType
    retries: int | None
    per_retry_timeout: float | None | UnsetType

    # When adding new fields, consider adding them to RequestKwargsForOperation instead.



from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.rpc import status_pb2 as _status_pb2
from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Operation(_message.Message):
    __slots__ = ["id", "description", "created_at", "created_by", "finished_at", "request", "request_headers", "resource_id", "status", "progress_data"]
    class RequestHeader(_message.Message):
        __slots__ = ["values"]
        VALUES_FIELD_NUMBER: _ClassVar[int]
        values: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...
    class RequestHeadersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Operation.RequestHeader
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Operation.RequestHeader, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    FINISHED_AT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    REQUEST_HEADERS_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_DATA_FIELD_NUMBER: _ClassVar[int]
    id: str
    description: str
    created_at: _timestamp_pb2.Timestamp
    created_by: str
    finished_at: _timestamp_pb2.Timestamp
    request: _any_pb2.Any
    request_headers: _containers.MessageMap[str, Operation.RequestHeader]
    resource_id: str
    status: _status_pb2.Status
    progress_data: _any_pb2.Any
    def __init__(self, id: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_by: _Optional[str] = ..., finished_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., request: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., request_headers: _Optional[_Mapping[str, Operation.RequestHeader]] = ..., resource_id: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., progress_data: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/suspension_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/iam/v1/suspension_state.proto\x12\rnebius.iam.v1*j\n\x0fSuspensionState\x12 \n\x1cSUSPENSION_STATE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x0e\n\nSUSPENDING\x10\x02\x12\r\n\tSUSPENDED\x10\x03\x12\x0c\n\x08RESUMING\x10\x04\x42[\n\x14\x61i.nebius.pub.iam.v1B\x14SuspensionStateProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.suspension_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\024SuspensionStateProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _globals['_SUSPENSIONSTATE']._serialized_start=55
  _globals['_SUSPENSIONSTATE']._serialized_end=161
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.common.v1 import operation_pb2 as _operation_pb2
from nebius.api.nebius.msp.serverless.v1alpha1 import endpoint_pb2 as _endpoint_pb2
from nebius.api.nebius.msp.v1alpha1 import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateEndpointRequest(_message.Message):
    __slots__ = ["metadata", "spec", "dry_run"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    DRY_RUN_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: _endpoint_pb2.EndpointSpec
    dry_run: bool
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[_endpoint_pb2.EndpointSpec, _Mapping]] = ..., dry_run: bool = ...) -> None: ...

class ListEndpointsResponse(_message.Message):
    __slots__ = ["items", "next_page_token"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_endpoint_pb2.Endpoint]
    next_page_token: str
    def __init__(self, items: _Optional[_Iterable[_Union[_endpoint_pb2.Endpoint, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/subnet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.vpc.v1alpha1 import pool_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_pool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nebius/vpc/v1alpha1/subnet.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1enebius/vpc/v1alpha1/pool.proto\"\xb8\x01\n\x06Subnet\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32\x1f.nebius.vpc.v1alpha1.SubnetSpecR\x04spec\x12\x39\n\x06status\x18\x03 \x01(\x0b\x32!.nebius.vpc.v1alpha1.SubnetStatusR\x06status\"\x9e\x01\n\nSubnetSpec\x12%\n\nnetwork_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\tnetworkId\x12=\n\x05pools\x18\x02 \x03(\x0b\x32\x1f.nebius.vpc.v1alpha1.SubnetPoolB\x06\xbaH\x03\xc8\x01\x01R\x05pools\x12*\n\x11\x65nable_egress_nat\x18\x03 \x01(\x08R\x0f\x65nableEgressNat\"q\n\nSubnetPool\x12\x39\n\x04spec\x18\x01 \x01(\x0b\x32#.nebius.vpc.v1alpha1.SubnetPoolSpecH\x00R\x04spec\x12\x19\n\x07pool_id\x18\x02 \x01(\tH\x00R\x06poolIdB\r\n\x04pool\x12\x05\xbaH\x02\x08\x01\"\x89\x01\n\x0eSubnetPoolSpec\x12@\n\x07version\x18\x01 \x01(\x0e\x32\x1e.nebius.vpc.v1alpha1.IpVersionB\x06\xbaH\x03\xc8\x01\x01R\x07version\x12\x35\n\x05\x63idrs\x18\x02 \x03(\x0b\x32\x1f.nebius.vpc.v1alpha1.SubnetCidrR\x05\x63idrs\"\xa0\x03\n\nSubnetCidr\x12\x9d\x02\n\x04\x63idr\x18\x01 \x01(\tB\x88\x02\xbaH\x84\x02\xba\x01\xac\x01\n\x11string.valid_cidr\x12.value must be a valid IP address, CIDR or mask\x1agthis == \'\' || this.matches(\'^/([0-9]|[1-9][0-9]|1[0-2][0-8])$\') || this.isIp() || this.isIpPrefix(true)\xba\x01N\n\x0fstring.ip_empty\x12/value is empty, which is not a valid IP address\x1a\nthis != \'\'\xc8\x01\x01R\x04\x63idr\x12@\n\x05state\x18\x02 \x01(\x0e\x32\".nebius.vpc.v1alpha1.PoolCidrStateB\x06\xbaH\x03\xc8\x01\x01R\x05state\x12\x30\n\x0c\x61llowed_mask\x18\x03 \x01(\x03\x42\r\xbaH\n\xc8\x01\x01\"\x05\x18\x80\x01(\x00R\x0b\x61llowedMask\"\xb3\x01\n\x0cSubnetStatus\x12=\n\x05state\x18\x01 \x01(\x0e\x32\'.nebius.vpc.v1alpha1.SubnetStatus.StateR\x05state\x12\x1d\n\nipv4_cidrs\x18\x02 \x03(\tR\tipv4Cidrs\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42^\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\x0bSubnetProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.subnet_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\013SubnetProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _SUBNETSPEC.fields_by_name['network_id']._options = None
  _SUBNETSPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001'
  _SUBNETSPEC.fields_by_name['pools']._options = None
  _SUBNETSPEC.fields_by_name['pools']._serialized_options = b'\272H\003\310\001\001'
  _SUBNETPOOL.oneofs_by_name['pool']._options = None
  _SUBNETPOOL.oneofs_by_name['pool']._serialized_options = b'\272H\002\010\001'
  _SUBNETPOOLSPEC.fields_by_name['version']._options = None
  _SUBNETPOOLSPEC.fields_by_name['version']._serialized_options = b'\272H\003\310\001\001'
  _SUBNETCIDR.fields_by_name['cidr']._options = None
  _SUBNETCIDR.fields_by_name['cidr']._serialized_options = b'\272H\204\002\272\001\254\001\n\021string.valid_cidr\022.value must be a valid IP address, CIDR or mask\032gthis == \'\' || this.matches(\'^/([0-9]|[1-9][0-9]|1[0-2][0-8])$\') || this.isIp() || this.isIpPrefix(true)\272\001N\n\017string.ip_empty\022/value is empty, which is not a valid IP address\032\nthis != \'\'\310\001\001'
  _SUBNETCIDR.fields_by_name['state']._options = None
  _SUBNETCIDR.fields_by_name['state']._serialized_options = b'\272H\003\310\001\001'
  _SUBNETCIDR.fields_by_name['allowed_mask']._options = None
  _SUBNETCIDR.fields_by_name['allowed_mask']._serialized_options = b'\272H\n\310\001\001\"\005\030\200\001(\000'
  _globals['_SUBNET']._serialized_start=152
  _globals['_SUBNET']._serialized_end=336
  _globals['_SUBNETSPEC']._serialized_start=339
  _globals['_SUBNETSPEC']._serialized_end=497
  _globals['_SUBNETPOOL']._serialized_start=499
  _globals['_SUBNETPOOL']._serialized_end=612
  _globals['_SUBNETPOOLSPEC']._serialized_start=615
  _globals['_SUBNETPOOLSPEC']._serialized_end=752
  _globals['_SUBNETCIDR']._serialized_start=755
  _globals['_SUBNETCIDR']._serialized_end=1171
  _globals['_SUBNETSTATUS']._serialized_start=1174
  _globals['_SUBNETSTATUS']._serialized_end=1353
  _globals['_SUBNETSTATUS_STATE']._serialized_start=1284
  _globals['_SUBNETSTATUS_STATE']._serialized_end=1353
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.iam.v1 import access_pb2 as _access_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AuthPublicKey(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: AuthPublicKeySpec
    status: AuthPublicKeyStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[AuthPublicKeySpec, _Mapping]] = ..., status: _Optional[_Union[AuthPublicKeyStatus, _Mapping]] = ...) -> None: ...

class AuthPublicKeySpec(_message.Message):
    __slots__ = ["account", "expires_at", "description", "data"]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    account: _access_pb2.Account
    expires_at: _timestamp_pb2.Timestamp
    description: str
    data: str
    def __init__(self, account: _Optional[_Union[_access_pb2.Account, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., description: _Optional[str] = ..., data: _Optional[str] = ...) -> None: ...

class AuthPublicKeyStatus(_message.Message):
    __slots__ = ["state", "fingerprint", "algorithm", "key_size"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[AuthPublicKeyStatus.State]
        ACTIVE: _ClassVar[AuthPublicKeyStatus.State]
        INACTIVE: _ClassVar[AuthPublicKeyStatus.State]
        EXPIRED: _ClassVar[AuthPublicKeyStatus.State]
        DELETING: _ClassVar[AuthPublicKeyStatus.State]
        DELETED: _ClassVar[AuthPublicKeyStatus.State]
    STATE_UNSPECIFIED: AuthPublicKeyStatus.State
    ACTIVE: AuthPublicKeyStatus.State
    INACTIVE: AuthPublicKeyStatus.State
    EXPIRED: AuthPublicKeyStatus.State
    DELETING: AuthPublicKeyStatus.State
    DELETED: AuthPublicKeyStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    KEY_SIZE_FIELD_NUMBER: _ClassVar[int]
    state: AuthPublicKeyStatus.State
    fingerprint: str
    algorithm: str
    key_size: int
    def __init__(self, state: _Optional[_Union[AuthPublicKeyStatus.State, str]] = ..., fingerprint: _Optional[str] = ..., algorithm: _Optional[str] = ..., key_size: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/pool_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import pool_pb2 as nebius_dot_vpc_dot_v1_dot_pool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nebius/vpc/v1/pool_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x18nebius/vpc/v1/pool.proto\"(\n\x0eGetPoolRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"W\n\x14GetPoolByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"s\n\x10ListPoolsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"{\n\x1cListPoolsBySourcePoolRequest\x12\x1f\n\x07pool_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06poolId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"f\n\x11ListPoolsResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x13.nebius.vpc.v1.PoolR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xd5\x02\n\x11\x43reatePoolRequest\x12\x8a\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc9\x01\xbaH\xc5\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xc8\x01\x01R\x08metadata\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32\x17.nebius.vpc.v1.PoolSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xca\x02\n\x11UpdatePoolRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12+\n\x04spec\x18\x02 \x01(\x0b\x32\x17.nebius.vpc.v1.PoolSpecR\x04spec\"+\n\x11\x44\x65letePoolRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xa0\x04\n\x0bPoolService\x12\x39\n\x03Get\x12\x1d.nebius.vpc.v1.GetPoolRequest\x1a\x13.nebius.vpc.v1.Pool\x12\x45\n\tGetByName\x12#.nebius.vpc.v1.GetPoolByNameRequest\x1a\x13.nebius.vpc.v1.Pool\x12I\n\x04List\x12\x1f.nebius.vpc.v1.ListPoolsRequest\x1a .nebius.vpc.v1.ListPoolsResponse\x12\x61\n\x10ListBySourcePool\x12+.nebius.vpc.v1.ListPoolsBySourcePoolRequest\x1a .nebius.vpc.v1.ListPoolsResponse\x12G\n\x06\x43reate\x12 .nebius.vpc.v1.CreatePoolRequest\x1a\x1b.nebius.common.v1.Operation\x12G\n\x06Update\x12 .nebius.vpc.v1.UpdatePoolRequest\x1a\x1b.nebius.common.v1.Operation\x12G\n\x06\x44\x65lete\x12 .nebius.vpc.v1.DeletePoolRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcBW\n\x14\x61i.nebius.pub.vpc.v1B\x10PoolServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.pool_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\020PoolServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETPOOLREQUEST.fields_by_name['id']._options = None
  _GETPOOLREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETPOOLBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETPOOLBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETPOOLBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETPOOLBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTPOOLSREQUEST.fields_by_name['parent_id']._options = None
  _LISTPOOLSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTPOOLSBYSOURCEPOOLREQUEST.fields_by_name['pool_id']._options = None
  _LISTPOOLSBYSOURCEPOOLREQUEST.fields_by_name['pool_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATEPOOLREQUEST.fields_by_name['metadata']._options = None
  _CREATEPOOLREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\305\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\310\001\001'
  _CREATEPOOLREQUEST.fields_by_name['spec']._options = None
  _CREATEPOOLREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEPOOLREQUEST.fields_by_name['metadata']._options = None
  _UPDATEPOOLREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _DELETEPOOLREQUEST.fields_by_name['id']._options = None
  _DELETEPOOLREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _POOLSERVICE._options = None
  _POOLSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETPOOLREQUEST']._serialized_start=199
  _globals['_GETPOOLREQUEST']._serialized_end=239
  _globals['_GETPOOLBYNAMEREQUEST']._serialized_start=241
  _globals['_GETPOOLBYNAMEREQUEST']._serialized_end=328
  _globals['_LISTPOOLSREQUEST']._serialized_start=330
  _globals['_LISTPOOLSREQUEST']._serialized_end=445
  _globals['_LISTPOOLSBYSOURCEPOOLREQUEST']._serialized_start=447
  _globals['_LISTPOOLSBYSOURCEPOOLREQUEST']._serialized_end=570
  _globals['_LISTPOOLSRESPONSE']._serialized_start=572
  _globals['_LISTPOOLSRESPONSE']._serialized_end=674
  _globals['_CREATEPOOLREQUEST']._serialized_start=677
  _globals['_CREATEPOOLREQUEST']._serialized_end=1018
  _globals['_UPDATEPOOLREQUEST']._serialized_start=1021
  _globals['_UPDATEPOOLREQUEST']._serialized_end=1351
  _globals['_DELETEPOOLREQUEST']._serialized_start=1353
  _globals['_DELETEPOOLREQUEST']._serialized_end=1396
  _globals['_POOLSERVICE']._serialized_start=1399
  _globals['_POOLSERVICE']._serialized_end=1943
# @@protoc_insertion_point(module_scope)



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.msp.mlflow.v1alpha1``"""

import builtins as builtins
import collections.abc as abc
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import nebius.aio.client as client
import nebius.aio.operation as operation
import nebius.aio.request as request_1
import nebius.aio.request_kwargs as request_kwargs
import nebius.api.nebius.common.v1 as v1_1
import nebius.api.nebius.common.v1.metadata_pb2 as metadata_pb2
import nebius.api.nebius.common.v1alpha1 as v1alpha1_2
import nebius.api.nebius.common.v1alpha1.operation_pb2 as operation_pb2
import nebius.api.nebius.msp.mlflow.v1alpha1.cluster_pb2 as cluster_pb2
import nebius.api.nebius.msp.mlflow.v1alpha1.cluster_service_pb2 as cluster_service_pb2
import nebius.api.nebius.msp.v1alpha1 as v1alpha1_1
import nebius.api.nebius.msp.v1alpha1.cluster_pb2 as cluster_pb2_1
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.unset as unset
import typing_extensions as typing_extensions
#@ local imports here @#

# file: nebius/msp/mlflow/v1alpha1/cluster.proto
class Cluster(pb_classes.Message):
    __PB2_CLASS__ = cluster_pb2.Cluster
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.Cluster",cluster_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "ClusterSpec|cluster_pb2.ClusterSpec|None|unset.UnsetType" = unset.Unset,
        status: "MlflowClusterStatus|cluster_pb2.MlflowClusterStatus|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
        if not isinstance(status, unset.UnsetType):
            self.status = status
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
            "status",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "ClusterSpec":
        return super()._get_field("spec", explicit_presence=False,
        wrap=ClusterSpec,
        )
    @spec.setter
    def spec(self, value: "ClusterSpec|cluster_pb2.ClusterSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    @builtins.property
    def status(self) -> "MlflowClusterStatus":
        return super()._get_field("status", explicit_presence=False,
        wrap=MlflowClusterStatus,
        )
    @status.setter
    def status(self, value: "MlflowClusterStatus|cluster_pb2.MlflowClusterStatus|None") -> None:
        return super()._set_field("status",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
        "status":"status",
    }
    
class ClusterSpec(pb_classes.Message):
    """
    Cluster specification
    """
    
    __PB2_CLASS__ = cluster_pb2.ClusterSpec
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.ClusterSpec",cluster_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        description: "builtins.str|None|unset.UnsetType" = unset.Unset,
        public_access: "builtins.bool|None|unset.UnsetType" = unset.Unset,
        admin_username: "builtins.str|None|unset.UnsetType" = unset.Unset,
        admin_password: "builtins.str|None|unset.UnsetType" = unset.Unset,
        service_account_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        storage_bucket_name: "builtins.str|None|unset.UnsetType" = unset.Unset,
        network_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        size: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(description, unset.UnsetType):
            self.description = description
        if not isinstance(public_access, unset.UnsetType):
            self.public_access = public_access
        if not isinstance(admin_username, unset.UnsetType):
            self.admin_username = admin_username
        if not isinstance(admin_password, unset.UnsetType):
            self.admin_password = admin_password
        if not isinstance(service_account_id, unset.UnsetType):
            self.service_account_id = service_account_id
        if not isinstance(storage_bucket_name, unset.UnsetType):
            self.storage_bucket_name = storage_bucket_name
        if not isinstance(network_id, unset.UnsetType):
            self.network_id = network_id
        if not isinstance(size, unset.UnsetType):
            self.size = size
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "description",
            "public_access",
            "admin_username",
            "admin_password",
            "service_account_id",
            "storage_bucket_name",
            "network_id",
            "size",
        ]
    
    @builtins.property
    def description(self) -> "builtins.str":
        """
        Description of the cluster.
        """
        
        return super()._get_field("description", explicit_presence=False,
        )
    @description.setter
    def description(self, value: "builtins.str|None") -> None:
        return super()._set_field("description",value,explicit_presence=False,
        )
    
    @builtins.property
    def public_access(self) -> "builtins.bool":
        """
        Either make cluster public accessible or accessible only via private VPC.
        """
        
        return super()._get_field("public_access", explicit_presence=False,
        )
    @public_access.setter
    def public_access(self, value: "builtins.bool|None") -> None:
        return super()._set_field("public_access",value,explicit_presence=False,
        )
    
    @builtins.property
    def admin_username(self) -> "builtins.str":
        """
        MLflow admin username.
        """
        
        return super()._get_field("admin_username", explicit_presence=False,
        )
    @admin_username.setter
    def admin_username(self, value: "builtins.str|None") -> None:
        return super()._set_field("admin_username",value,explicit_presence=False,
        )
    
    @builtins.property
    def admin_password(self) -> "builtins.str":
        """
        MLflow admin password.
        """
        
        return super()._get_field("admin_password", explicit_presence=False,
        )
    @admin_password.setter
    def admin_password(self, value: "builtins.str|None") -> None:
        return super()._set_field("admin_password",value,explicit_presence=False,
        )
    
    @builtins.property
    def service_account_id(self) -> "builtins.str":
        """
        Id of the service account that will be used to access S3 bucket (and create one if not provided).
        """
        
        return super()._get_field("service_account_id", explicit_presence=False,
        )
    @service_account_id.setter
    def service_account_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("service_account_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def storage_bucket_name(self) -> "builtins.str":
        """
        Name of the Nebius S3 bucket for MLflow artifacts. If not provided, will be created under the same parent.
        """
        
        return super()._get_field("storage_bucket_name", explicit_presence=False,
        )
    @storage_bucket_name.setter
    def storage_bucket_name(self, value: "builtins.str|None") -> None:
        return super()._set_field("storage_bucket_name",value,explicit_presence=False,
        )
    
    @builtins.property
    def network_id(self) -> "builtins.str":
        """
        ID of the vpc network.
        """
        
        return super()._get_field("network_id", explicit_presence=False,
        )
    @network_id.setter
    def network_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("network_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def size(self) -> "builtins.str":
        """
        Size defines how much resources will be allocated to mlflow
        See supported sizes in the documentation. Default size is the smallest available in the region.
        """
        
        return super()._get_field("size", explicit_presence=False,
        )
    @size.setter
    def size(self, value: "builtins.str|None") -> None:
        return super()._set_field("size",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "description":"description",
        "public_access":"public_access",
        "admin_username":"admin_username",
        "admin_password":"admin_password",
        "service_account_id":"service_account_id",
        "storage_bucket_name":"storage_bucket_name",
        "network_id":"network_id",
        "size":"size",
    }
    
class MlflowClusterStatus(pb_classes.Message):
    __PB2_CLASS__ = cluster_pb2.MlflowClusterStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.MlflowClusterStatus",cluster_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        phase: "v1alpha1_1.ClusterStatus.Phase|cluster_pb2_1.ClusterStatus.Phase|None|unset.UnsetType" = unset.Unset,
        state: "v1alpha1_1.ClusterStatus.State|cluster_pb2_1.ClusterStatus.State|None|unset.UnsetType" = unset.Unset,
        tracking_endpoint: "builtins.str|None|unset.UnsetType" = unset.Unset,
        effective_storage_bucket_name: "builtins.str|None|unset.UnsetType" = unset.Unset,
        experiments_count: "builtins.int|None|unset.UnsetType" = unset.Unset,
        mlflow_version: "builtins.str|None|unset.UnsetType" = unset.Unset,
        tracking_endpoints: "Endpoints|cluster_pb2.Endpoints|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(phase, unset.UnsetType):
            self.phase = phase
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(tracking_endpoint, unset.UnsetType):
            self.tracking_endpoint = tracking_endpoint
        if not isinstance(effective_storage_bucket_name, unset.UnsetType):
            self.effective_storage_bucket_name = effective_storage_bucket_name
        if not isinstance(experiments_count, unset.UnsetType):
            self.experiments_count = experiments_count
        if not isinstance(mlflow_version, unset.UnsetType):
            self.mlflow_version = mlflow_version
        if not isinstance(tracking_endpoints, unset.UnsetType):
            self.tracking_endpoints = tracking_endpoints
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "phase",
            "state",
            "tracking_endpoint",
            "effective_storage_bucket_name",
            "experiments_count",
            "mlflow_version",
            "tracking_endpoints",
        ]
    
    @builtins.property
    def phase(self) -> "v1alpha1_1.ClusterStatus.Phase":
        """
        Current phase of the cluster.
        """
        
        return super()._get_field("phase", explicit_presence=False,
        wrap=v1alpha1_1.ClusterStatus.Phase,
        )
    @phase.setter
    def phase(self, value: "v1alpha1_1.ClusterStatus.Phase|cluster_pb2_1.ClusterStatus.Phase|None") -> None:
        return super()._set_field("phase",value,explicit_presence=False,
        )
    
    @builtins.property
    def state(self) -> "v1alpha1_1.ClusterStatus.State":
        """
        State reflects substatus of the phase to define whether it's healthy or not.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=v1alpha1_1.ClusterStatus.State,
        )
    @state.setter
    def state(self, value: "v1alpha1_1.ClusterStatus.State|cluster_pb2_1.ClusterStatus.State|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def tracking_endpoint(self) -> "builtins.str":
        """
        Tracking endpoint url.
        Will be removed soon in favor of private_tracking_endpoint and public_tracking_endpoint.
        """
        
        return super()._get_field("tracking_endpoint", explicit_presence=False,
        )
    @tracking_endpoint.setter
    def tracking_endpoint(self, value: "builtins.str|None") -> None:
        return super()._set_field("tracking_endpoint",value,explicit_presence=False,
        )
    
    @builtins.property
    def effective_storage_bucket_name(self) -> "builtins.str":
        """
        Name of the Nebius S3 bucket for MLflow artifacts.
        """
        
        return super()._get_field("effective_storage_bucket_name", explicit_presence=False,
        )
    @effective_storage_bucket_name.setter
    def effective_storage_bucket_name(self, value: "builtins.str|None") -> None:
        return super()._set_field("effective_storage_bucket_name",value,explicit_presence=False,
        )
    
    @builtins.property
    def experiments_count(self) -> "builtins.int":
        """
        Count of experiments in the MLflow cluster
        """
        
        return super()._get_field("experiments_count", explicit_presence=False,
        )
    @experiments_count.setter
    def experiments_count(self, value: "builtins.int|None") -> None:
        return super()._set_field("experiments_count",value,explicit_presence=False,
        )
    
    @builtins.property
    def mlflow_version(self) -> "builtins.str":
        """
        MLflow version
        """
        
        return super()._get_field("mlflow_version", explicit_presence=False,
        )
    @mlflow_version.setter
    def mlflow_version(self, value: "builtins.str|None") -> None:
        return super()._set_field("mlflow_version",value,explicit_presence=False,
        )
    
    @builtins.property
    def tracking_endpoints(self) -> "Endpoints":
        """
        Public and private tracking endpoints
        """
        
        return super()._get_field("tracking_endpoints", explicit_presence=False,
        wrap=Endpoints,
        )
    @tracking_endpoints.setter
    def tracking_endpoints(self, value: "Endpoints|cluster_pb2.Endpoints|None") -> None:
        return super()._set_field("tracking_endpoints",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "phase":"phase",
        "state":"state",
        "tracking_endpoint":"tracking_endpoint",
        "effective_storage_bucket_name":"effective_storage_bucket_name",
        "experiments_count":"experiments_count",
        "mlflow_version":"mlflow_version",
        "tracking_endpoints":"tracking_endpoints",
    }
    
class Endpoints(pb_classes.Message):
    __PB2_CLASS__ = cluster_pb2.Endpoints
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.Endpoints",cluster_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        private: "builtins.str|None|unset.UnsetType" = unset.Unset,
        public: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(private, unset.UnsetType):
            self.private = private
        if not isinstance(public, unset.UnsetType):
            self.public = public
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "private",
            "public",
        ]
    
    @builtins.property
    def private(self) -> "builtins.str":
        """
        Private endpoint
        """
        
        return super()._get_field("private", explicit_presence=False,
        )
    @private.setter
    def private(self, value: "builtins.str|None") -> None:
        return super()._set_field("private",value,explicit_presence=False,
        )
    
    @builtins.property
    def public(self) -> "builtins.str":
        """
        Public endpoint
        """
        
        return super()._get_field("public", explicit_presence=False,
        )
    @public.setter
    def public(self, value: "builtins.str|None") -> None:
        return super()._set_field("public",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "private":"private",
        "public":"public",
    }
    
# file: nebius/msp/mlflow/v1alpha1/cluster_service.proto
class GetClusterRequest(pb_classes.Message):
    __PB2_CLASS__ = cluster_service_pb2.GetClusterRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.GetClusterRequest",cluster_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the cluster to retrieve.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class GetClusterByNameRequest(pb_classes.Message):
    __PB2_CLASS__ = cluster_service_pb2.GetClusterByNameRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.GetClusterByNameRequest",cluster_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        name: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(name, unset.UnsetType):
            self.name = name
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "name",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Identifier of IAM container to get cluster from.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def name(self) -> "builtins.str":
        """
        Name of the cluster.
        """
        
        return super()._get_field("name", explicit_presence=False,
        )
    @name.setter
    def name(self, value: "builtins.str|None") -> None:
        return super()._set_field("name",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "name":"name",
    }
    
class ListClustersRequest(pb_classes.Message):
    __PB2_CLASS__ = cluster_service_pb2.ListClustersRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.ListClustersRequest",cluster_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Identifier of IAM container to list clusters from.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        """
        Specifies the maximum number of items to return in the response. Default value is 100.
        """
        
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        """
        Token for pagination, allowing the retrieval of the next set of results.
        """
        
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
    }
    
class ListClustersResponse(pb_classes.Message):
    __PB2_CLASS__ = cluster_service_pb2.ListClustersResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.ListClustersResponse",cluster_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        items: "abc.Iterable[Cluster]|None|unset.UnsetType" = unset.Unset,
        next_page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(items, unset.UnsetType):
            self.items = items
        if not isinstance(next_page_token, unset.UnsetType):
            self.next_page_token = next_page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "items",
            "next_page_token",
        ]
    
    @builtins.property
    def items(self) -> "abc.MutableSequence[Cluster]":
        """
        List of clusters.
        """
        
        return super()._get_field("items", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(Cluster,None,None),
        )
    @items.setter
    def items(self, value: "abc.Iterable[Cluster]|None") -> None:
        return super()._set_field("items",value,explicit_presence=False,
        )
    
    @builtins.property
    def next_page_token(self) -> "builtins.str":
        """
        Token for pagination, indicating the next set of results can be retrieved using this token.
        """
        
        return super()._get_field("next_page_token", explicit_presence=False,
        )
    @next_page_token.setter
    def next_page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("next_page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "items":"items",
        "next_page_token":"next_page_token",
    }
    
class CreateClusterRequest(pb_classes.Message):
    __PB2_CLASS__ = cluster_service_pb2.CreateClusterRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.CreateClusterRequest",cluster_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        metadata: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None|unset.UnsetType" = unset.Unset,
        spec: "ClusterSpec|cluster_pb2.ClusterSpec|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(metadata, unset.UnsetType):
            self.metadata = metadata
        if not isinstance(spec, unset.UnsetType):
            self.spec = spec
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "metadata",
            "spec",
        ]
    
    @builtins.property
    def metadata(self) -> "v1_1.ResourceMetadata":
        """
        Metadata associated with the new cluster. Must include parent_id in which we create the cluster.
        """
        
        return super()._get_field("metadata", explicit_presence=False,
        wrap=v1_1.ResourceMetadata,
        )
    @metadata.setter
    def metadata(self, value: "v1_1.ResourceMetadata|metadata_pb2.ResourceMetadata|None") -> None:
        return super()._set_field("metadata",value,explicit_presence=False,
        )
    
    @builtins.property
    def spec(self) -> "ClusterSpec":
        """
        Specification for the new cluster.
        """
        
        return super()._get_field("spec", explicit_presence=False,
        wrap=ClusterSpec,
        )
    @spec.setter
    def spec(self, value: "ClusterSpec|cluster_pb2.ClusterSpec|None") -> None:
        return super()._set_field("spec",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "metadata":"metadata",
        "spec":"spec",
    }
    
class DeleteClusterRequest(pb_classes.Message):
    __PB2_CLASS__ = cluster_service_pb2.DeleteClusterRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.mlflow.v1alpha1.DeleteClusterRequest",cluster_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the cluster to delete.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    

class ClusterServiceClient(client.ClientWithOperations[v1alpha1_2.Operation,v1alpha1_2.OperationServiceClient]):
    """
    This class provides the client methods for the ``.nebius.msp.mlflow.v1alpha1.ClusterService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.msp.mlflow.v1alpha1.ClusterService",cluster_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.msp.mlflow.v1alpha1.ClusterService"
    __operation_type__ = v1alpha1_2.Operation
    __operation_service_class__ = v1alpha1_2.OperationServiceClient
    __operation_source_method__ = "Create"
    """The method name that can be used to fetch the address channel for the operation."""
    
    def get(self,
        request: "GetClusterRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["GetClusterRequest","Cluster"]:
        """
        Returns the specified cluster.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.msp.mlflow.v1alpha1.GetClusterRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.msp.mlflow.v1alpha1.Cluster`.
        """
        
        return super().request(
            method="Get",
            request=request,
            result_pb2_class=cluster_pb2.Cluster,
            result_wrapper=pb_classes.simple_wrapper(Cluster),
            **kwargs,
        )
    
    def get_by_name(self,
        request: "GetClusterByNameRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["GetClusterByNameRequest","Cluster"]:
        """
        Returns the specified cluster.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.msp.mlflow.v1alpha1.GetClusterByNameRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.msp.mlflow.v1alpha1.Cluster`.
        """
        
        return super().request(
            method="GetByName",
            request=request,
            result_pb2_class=cluster_pb2.Cluster,
            result_wrapper=pb_classes.simple_wrapper(Cluster),
            **kwargs,
        )
    
    def list(self,
        request: "ListClustersRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["ListClustersRequest","ListClustersResponse"]:
        """
        Retrieves a list of clusters.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.msp.mlflow.v1alpha1.ListClustersRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.msp.mlflow.v1alpha1.ListClustersResponse`.
        """
        
        return super().request(
            method="List",
            request=request,
            result_pb2_class=cluster_service_pb2.ListClustersResponse,
            result_wrapper=pb_classes.simple_wrapper(ListClustersResponse),
            **kwargs,
        )
    
    def create(self,
        request: "CreateClusterRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["CreateClusterRequest","operation.Operation[v1alpha1_2.Operation]"]:
        """
        Creates a cluster.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.msp.mlflow.v1alpha1.CreateClusterRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1alpha1.Operation`.
        """
        
        return super().request(
            method="Create",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    
    def delete(self,
        request: "DeleteClusterRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request_1.Request["DeleteClusterRequest","operation.Operation[v1alpha1_2.Operation]"]:
        """
        Delete a cluster.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.msp.mlflow.v1alpha1.DeleteClusterRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.common.v1alpha1.Operation`.
        """
        
        return super().request(
            method="Delete",
            request=request,
            result_pb2_class=operation_pb2.Operation,
            result_wrapper=operation.Operation,
            **kwargs,
        )
    

__all__ = [
    #@ local import names here @#
    "Cluster",
    "ClusterSpec",
    "MlflowClusterStatus",
    "Endpoints",
    "GetClusterRequest",
    "GetClusterByNameRequest",
    "ListClustersRequest",
    "ListClustersResponse",
    "CreateClusterRequest",
    "DeleteClusterRequest",
    "ClusterServiceClient",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/route_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import route_pb2 as nebius_dot_vpc_dot_v1_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/vpc/v1/route_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x19nebius/vpc/v1/route.proto\")\n\x0fGetRouteRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"X\n\x15GetRouteByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"t\n\x11ListRoutesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"h\n\x12ListRoutesResponse\x12*\n\x05items\x18\x01 \x03(\x0b\x32\x14.nebius.vpc.v1.RouteR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xd7\x02\n\x12\x43reateRouteRequest\x12\x8a\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc9\x01\xbaH\xc5\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xc8\x01\x01R\x08metadata\x12\x34\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.vpc.v1.RouteSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xcc\x02\n\x12UpdateRouteRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.vpc.v1.RouteSpecR\x04spec\",\n\x12\x44\x65leteRouteRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xc7\x03\n\x0cRouteService\x12;\n\x03Get\x12\x1e.nebius.vpc.v1.GetRouteRequest\x1a\x14.nebius.vpc.v1.Route\x12G\n\tGetByName\x12$.nebius.vpc.v1.GetRouteByNameRequest\x1a\x14.nebius.vpc.v1.Route\x12K\n\x04List\x12 .nebius.vpc.v1.ListRoutesRequest\x1a!.nebius.vpc.v1.ListRoutesResponse\x12H\n\x06\x43reate\x12!.nebius.vpc.v1.CreateRouteRequest\x1a\x1b.nebius.common.v1.Operation\x12H\n\x06Update\x12!.nebius.vpc.v1.UpdateRouteRequest\x1a\x1b.nebius.common.v1.Operation\x12H\n\x06\x44\x65lete\x12!.nebius.vpc.v1.DeleteRouteRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcBX\n\x14\x61i.nebius.pub.vpc.v1B\x11RouteServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.route_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\021RouteServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETROUTEREQUEST.fields_by_name['id']._options = None
  _GETROUTEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETROUTEBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETROUTEBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETROUTEBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETROUTEBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTROUTESREQUEST.fields_by_name['parent_id']._options = None
  _LISTROUTESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATEROUTEREQUEST.fields_by_name['metadata']._options = None
  _CREATEROUTEREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\305\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\310\001\001'
  _CREATEROUTEREQUEST.fields_by_name['spec']._options = None
  _CREATEROUTEREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEROUTEREQUEST.fields_by_name['metadata']._options = None
  _UPDATEROUTEREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _DELETEROUTEREQUEST.fields_by_name['id']._options = None
  _DELETEROUTEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ROUTESERVICE._options = None
  _ROUTESERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETROUTEREQUEST']._serialized_start=201
  _globals['_GETROUTEREQUEST']._serialized_end=242
  _globals['_GETROUTEBYNAMEREQUEST']._serialized_start=244
  _globals['_GETROUTEBYNAMEREQUEST']._serialized_end=332
  _globals['_LISTROUTESREQUEST']._serialized_start=334
  _globals['_LISTROUTESREQUEST']._serialized_end=450
  _globals['_LISTROUTESRESPONSE']._serialized_start=452
  _globals['_LISTROUTESRESPONSE']._serialized_end=556
  _globals['_CREATEROUTEREQUEST']._serialized_start=559
  _globals['_CREATEROUTEREQUEST']._serialized_end=902
  _globals['_UPDATEROUTEREQUEST']._serialized_start=905
  _globals['_UPDATEROUTEREQUEST']._serialized_end=1237
  _globals['_DELETEROUTEREQUEST']._serialized_start=1239
  _globals['_DELETEROUTEREQUEST']._serialized_end=1283
  _globals['_ROUTESERVICE']._serialized_start=1286
  _globals['_ROUTESERVICE']._serialized_end=1741
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    STATE_UNSPECIFIED: _ClassVar[State]
    STATE_SCHEDULED: _ClassVar[State]
    STATE_IN_PROGRESS: _ClassVar[State]
    STATE_FINISHED: _ClassVar[State]
    STATE_ERROR: _ClassVar[State]
    STATE_CANCELLED: _ClassVar[State]
STATE_UNSPECIFIED: State
STATE_SCHEDULED: State
STATE_IN_PROGRESS: State
STATE_FINISHED: State
STATE_ERROR: State
STATE_CANCELLED: State

class Maintenance(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: MaintenanceSpec
    status: MaintenanceStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[MaintenanceSpec, _Mapping]] = ..., status: _Optional[_Union[MaintenanceStatus, _Mapping]] = ...) -> None: ...

class MaintenanceSpec(_message.Message):
    __slots__ = ["scheduled_at"]
    SCHEDULED_AT_FIELD_NUMBER: _ClassVar[int]
    scheduled_at: _timestamp_pb2.Timestamp
    def __init__(self, scheduled_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class MaintenanceStatus(_message.Message):
    __slots__ = ["affected_resources", "started_at", "finished_at", "state", "reschedulable"]
    AFFECTED_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    STARTED_AT_FIELD_NUMBER: _ClassVar[int]
    FINISHED_AT_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    RESCHEDULABLE_FIELD_NUMBER: _ClassVar[int]
    affected_resources: _containers.RepeatedCompositeFieldContainer[Resource]
    started_at: _timestamp_pb2.Timestamp
    finished_at: _timestamp_pb2.Timestamp
    state: State
    reschedulable: bool
    def __init__(self, affected_resources: _Optional[_Iterable[_Union[Resource, _Mapping]]] = ..., started_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., finished_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[State, str]] = ..., reschedulable: bool = ...) -> None: ...

class Resource(_message.Message):
    __slots__ = ["id", "parent_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    parent_id: str
    def __init__(self, id: _Optional[str] = ..., parent_id: _Optional[str] = ...) -> None: ...



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.compute.v1 import platform_pb2 as _platform_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListPlatformsRequest(_message.Message):
    __slots__ = ["page_size", "page_token", "parent_id"]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    parent_id: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., parent_id: _Optional[str] = ...) -> None: ...

class ListPlatformsResponse(_message.Message):
    __slots__ = ["items", "next_page_token"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_platform_pb2.Platform]
    next_page_token: str
    def __init__(self, items: _Optional[_Iterable[_Union[_platform_pb2.Platform, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/offer_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/billing/v1alpha1/offer_type.proto\x12\x17nebius.billing.v1alpha1*F\n\tOfferType\x12\x1a\n\x16OFFER_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19OFFER_TYPE_CONTRACT_PRICE\x10\x01\x42i\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x0eOfferTypeProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.offer_type_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\016OfferTypeProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _globals['_OFFERTYPE']._serialized_start=69
  _globals['_OFFERTYPE']._serialized_end=139
# @@protoc_insertion_point(module_scope)
